@@ -16,7 +16,7 @@ import os
 import re
 
 class Obraz(Mail_sender):
-  def __init__(self, obraz=None, book=None, adress_book='mto_with_adress_108847.csv', model_chekpoint='sergiyvl/model_65000_20ep'):
+  def __init__(self, obraz=None, book=None, adress_book='mto_148000_with_adress_newtriodi_08032022.csv', model_chekpoint='sergiyvl/model_65000_20ep'):
     """
     Класс для работы с образом. 
     obraz - str, сам образ. Обязателен при создании объекта. Образ менять нельзя (не имеет смысла).
@@ -420,7 +420,7 @@ class Obraz(Mail_sender):
     i = 0
     num = input("Оставить нумерацию? введите Да или Нет").strip().upper()
     for text in self.texts_with_key_key[:h_m_with_keykey]:
-      if num != "Нет".upper():
+      if num == "Нет".upper():
         p = document.add_paragraph(text[0]+"  ")        
       else:  
         i += 1
@@ -455,7 +455,7 @@ class Obraz(Mail_sender):
     i = 0
     num = input("Оставить нумерацию? введите Да или Нет").strip().upper()
     for text in self._fast_book:
-      if num != "Нет".upper():
+      if num == "Нет".upper():
         p = document.add_paragraph(text[0]+"  ")        
       else:  
         i += 1
